@@ -1,5 +1,6 @@
 use crate::{utils::Url, NoteError};
-use rsass::Error;
+use rsass::{Error, SourcePos};
+use std::ops::Range;
 
 impl From<Error> for NoteError {
     fn from(e: Error) -> Self {
@@ -16,8 +17,11 @@ impl From<Error> for NoteError {
             Error::BadCall(_, _, _) => {
                 unimplemented!()
             }
-            Error::InvalidFunctionName(_) => {
-                unimplemented!()
+            Error::InvalidFunctionName(r) => {
+                // TODO: name
+                let mut error = Self::runtime_error(&format!("Invalid function name"));
+                error.range = get_range(&r);
+                error
             }
             Error::BadValue(_) => {
                 unimplemented!()
@@ -31,8 +35,9 @@ impl From<Error> for NoteError {
             Error::BadRange(_) => {
                 unimplemented!()
             }
-            Error::ParseError(_) => {
-                unimplemented!()
+            Error::ParseError(e) => {
+                let error = Self::runtime_error(e.to_string());
+                error
             }
             Error::UndefinedVariable(_) => {
                 unimplemented!()
@@ -46,3 +51,7 @@ impl From<Error> for NoteError {
         }
     }
 }
+
+fn get_range(_: &SourcePos) -> Option<Range<usize>> {
+    None
+}
