@@ -7,9 +7,9 @@ use std::{
 };
 use yggdrasil_shared::records::Url;
 
+mod error_3rd;
 mod error_custom;
 mod error_std;
-mod error_3rd;
 
 pub type Result<T> = std::result::Result<T, NoteError>;
 
@@ -25,11 +25,12 @@ pub enum NoteErrorKind {
     IOError(std::io::Error),
     FormatError(std::fmt::Error),
     TypeMismatch(String),
+    SyntaxError(String),
     RuntimeError(String),
     /// A forbidden cst_node encountered
     Unreachable,
-    // #[error(transparent)]
-    // UnknownError(#[from] anyhow::Error),
+    /* #[error(transparent)]
+     * UnknownError(#[from] anyhow::Error), */
 }
 
 impl NoteError {
@@ -65,6 +66,7 @@ macro_rules! error_msg {
 }
 
 error_msg![
+    syntax_error => SyntaxError,
     type_mismatch => TypeMismatch,
     runtime_error => RuntimeError,
 ];
@@ -94,12 +96,16 @@ impl Display for NoteErrorKind {
             Self::FormatError(e) => {
                 write!(f, "{}", e)
             }
+            Self::SyntaxError(msg) => {
+                f.write_str("SyntaxError: ")?;
+                f.write_str(msg)
+            }
             Self::TypeMismatch(msg) => {
-                f.write_str("TypeMismatch: ")?;
+                f.write_str("TypeError: ")?;
                 f.write_str(msg)
             }
             Self::RuntimeError(msg) => {
-                f.write_str("TypeMismatch: ")?;
+                f.write_str("RuntimeError: ")?;
                 f.write_str(msg)
             }
             Self::Unreachable => {
